==> picoSQL-1.5.2-src.zip: picoSQL-1.5.2/sqlengine/odbcdate.h <==
/*
_____       _    _    Corso   Italia,  178
(_|__   .  (_   |_|_  56125           Pisa
(_|_) |)|(()_)()| |   tel.  +39  050 46380
  |   |               picosoft@picosoft.it

 Copyright (C) Picosoft s.r.l. 1995-2002

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/
# ifndef odbcdate_h
# define odbcdate_h "$Id: odbcdate.h 5.0 1999/10/08 10:17:43 picoSoft Exp Marco $"
# ifndef datatype_h
# include "datatype.h"
# endif
# ifndef dberror_h
# include "dberror.h"
# endif

extern "C" {
# include <time.h>
}

# include "token.h"

const char * isStringTimeStamp(const char *Buffer, long len);
Error StringToTimeStamp (TIMESTAMP_STRUCT * ts,
                         const char *dateBuffer,
                         long & len,
                         const char *fmt,
                         long jStart);
Error TimeStampToString (const TIMESTAMP_STRUCT * its,
                         char *dateBuffer,
                         const char *fmt,
                         long jStart);
PBool isTimeStampOk (TIMESTAMP_STRUCT *ts);
long ToJulian (const TIMESTAMP_STRUCT *ts);
void FromJulian (TIMESTAMP_STRUCT *ts, long jdate);
char * CurrentTime (time_t tNow, const char *format, long jStart, int yearToAdd);
double Extract (const char *val, toknum what, const char *fmt, long jStart);
                   
# endif

==> picoSQL-2.0.2-src.zip: picoSQL-2.0.2/sqlengine/odbcdate.h <==
/*
_____       _    _    Corso   Italia,  178
(_|__   .  (_   |_|_  56125           Pisa
(_|_) |)|(()_)()| |   tel.  +39  050 46380
  |   |               picosoft@picosoft.it

 Copyright (C) Picosoft s.r.l. 1995-2002

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/
# ifndef odbcdate_h
# define odbcdate_h "$Id: odbcdate.h 5.0 1999/10/08 10:17:43 picoSoft Exp Marco $"
# ifndef datatype_h
# include "datatype.h"
# endif
# ifndef dberror_h
# include "dberror.h"
# endif

extern "C" {
# include <time.h>
}

# include "token.h"

const char * isStringTimeStamp(const char *Buffer, long len);
Error StringToTimeStamp (TIMESTAMP_STRUCT * ts,
                         const char *dateBuffer,
                         long & len,
                         const char *fmt,
                         long jStart);
Error TimeStampToString (const TIMESTAMP_STRUCT * its,
                         char *dateBuffer,
                         const char *fmt,
                         long jStart);
PBool isTimeStampOk (TIMESTAMP_STRUCT *ts);
long ToJulian (const TIMESTAMP_STRUCT *ts);
void FromJulian (TIMESTAMP_STRUCT *ts, long jdate);
char * CurrentTime (time_t tNow,const char *format,long jStart,int yearToAdd);
double Extract (const char *val, toknum what, const char *fmt, long jStart);
char * addToTimestamp(const char *dateBuffer,
                      const char *dateFormat, double inc, PBool sub = false);

# endif
